antares.apps.message.service package
====================================

Submodules
----------

antares.apps.message.service.message\_manager module
----------------------------------------------------

.. automodule:: antares.apps.message.service.message_manager
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: antares.apps.message.service
   :members:
   :undoc-members:
   :show-inheritance:
